##  Manage Roles and Permissions
In SAP LeanIX, permissions are role-based. Users with specific roles receive all permissions associated with those roles. Here are the standard user roles:
  * **Viewer** : Has view permissions for fact sheets, can subscribe to them, and comment.
  * **Member** : Has edit permissions for fact sheets and can create new ones.
  * **Admin** : Has all permissions of a member and administrator permissions for a workspace.


As an admin, you configure permissions for non-admin roles, including permissions for fact sheets and other entities. For more information, see [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.").
If you use SSO for both authentication and authorization, you can create custom user roles to define more granular permission levels for each role. For more details, see [Custom User Roles](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__custom_user_roles).
To learn more about managing users and configuring advanced access settings, see [User and Access Management](https://help.sap.com/docs/leanix/ea/user-and-access-management?locale=en-US&state=PRODUCTION&version=CLOUD "Efficiently manage user access and authorization to ensure the right people have the appropriate permissions.").
